@@ -61,8 +61,8 @@ impl SeedCipherBuilder {
                 // return the encrypted seed cipher struct
                 Ok(SeedCipher::PwHash {
                     salt: salt.into(),
-                    mem_limit: limits.as_mem_limit() as u32,
-                    ops_limit: limits.as_ops_limit() as u32,
+                    mem_limit: limits.as_mem_limit(),
+                    ops_limit: limits.as_ops_limit(),
                     header: header.into(),
                     cipher: cipher.into(),
                 })
@@ -96,8 +96,8 @@ impl SeedCipherBuilder {
                 // return the encrypted seed cipher struct
                 Ok(SeedCipher::SecurityQuestions {
                     salt: salt.into(),
-                    mem_limit: limits.as_mem_limit() as u32,
-                    ops_limit: limits.as_ops_limit() as u32,
+                    mem_limit: limits.as_mem_limit(),
+                    ops_limit: limits.as_ops_limit(),
                     question_list,
                     header: header.into(),
                     cipher: cipher.into(),
@@ -275,6 +275,8 @@ impl LockedSeedCipherSecurityQuestions {
 }
 
 /// Enum of Locked SeedCipher types handled by this library.
+///
+/// These are obtained by calling [crate::UnlockedSeedBundle::from_locked].
 #[non_exhaustive]
 #[derive(Debug)]
 pub enum LockedSeedCipher {
